@@ -21,10 +21,6 @@ project = 'TemGym'
 copyright = '2022, David Landers'
 author = 'David Landers'
 
-# The full version, including alpha/beta/rc tags
-release = '0.5'
-
-
 # -- General configuration ---------------------------------------------------
 
 # Add any Sphinx extension module names here, as strings. They can be
