@@ -1,4 +1,4 @@
-import geometry as geom
+import temgymbasic.geometry as geom
 from gui import *
 import pyqtgraph.opengl as gl
 import numpy as np
